pub struct StaticFileHandler { /* private fields */ }Expand description
trillium handler to serve static files from the filesystem
Implementations
Sourceimpl StaticFileHandler
impl StaticFileHandler
Sourcepub fn new(fs_root: impl AsRef<Path>) -> Self
pub fn new(fs_root: impl AsRef<Path>) -> Self
builds a new StaticFileHandler
If the fs_root is a file instead of a directory, that file will be served at all paths.
use trillium_static::{StaticFileHandler, crate_relative_path};
use trillium_testing::TestServer;
let mut handler = StaticFileHandler::new(crate_relative_path!("examples/files"));
let app = TestServer::new(handler).await;
app.get("/").await.assert_status(Status::NotFound); // no index file configured
app.get("/index.html")
.await
.assert_ok()
.assert_body("<h1>hello world</h1>\n")
.assert_header("content-type", "text/html; charset=utf-8");Sourcepub fn without_etag_header(self) -> Self
pub fn without_etag_header(self) -> Self
do not set an etag header
Sourcepub fn without_modified_header(self) -> Self
pub fn without_modified_header(self) -> Self
do not set last-modified header
Sourcepub fn with_index_file(self, file: &str) -> Self
pub fn with_index_file(self, file: &str) -> Self
sets the index file on this StaticFileHandler
use trillium_static::{StaticFileHandler, crate_relative_path};
let handler = StaticFileHandler::new(crate_relative_path!("examples/files"))
.with_index_file("index.html");
let app = TestServer::new(handler).await;
app.get("/")
.await
.assert_ok()
.assert_body("<h1>hello world</h1>\n")
.assert_header("content-type", "text/html; charset=utf-8");Trait Implementations
Sourceimpl Debug for StaticFileHandler
impl Debug for StaticFileHandler
Sourceimpl Handler for StaticFileHandler
impl Handler for StaticFileHandler
Sourceasync fn init(&mut self, _info: &mut Info)
async fn init(&mut self, _info: &mut Info)
Performs one-time async set up on a mutable borrow of the Handler before the server starts
accepting requests. This allows a Handler to be defined in synchronous code but perform
async setup such as establishing a database connection or fetching some state from an
external source. This is optional, and chances are high that you do not need this. Read more
Sourceasync fn run(&self, conn: Conn) -> Conn
async fn run(&self, conn: Conn) -> Conn
Executes this handler, performing any modifications to the Conn that are desired.
Sourcefn before_send(&self, conn: Conn) -> impl Future<Output = Conn> + Send
fn before_send(&self, conn: Conn) -> impl Future<Output = Conn> + Send
Performs any final modifications to this conn after all handlers have been run. Although
this is a slight deviation from the simple conn->conn->conn chain represented by most
Handlers, it provides an easy way for libraries to effectively inject a second handler into
a response chain. This is useful for loggers that need to record information both before and
after other handlers have run, as well as database transaction handlers and similar library
code. Read more
Sourcefn has_upgrade(&self, upgrade: &Upgrade) -> bool
fn has_upgrade(&self, upgrade: &Upgrade) -> bool
predicate function answering the question of whether this Handler would like to take
ownership of the negotiated Upgrade. If this returns true, you must implement
Handler::upgrade. The first handler that responds true to this will receive
ownership of the trillium::Upgrade in a subsequent call to
Handler::upgradeSourcefn upgrade(&self, upgrade: Upgrade) -> impl Future<Output = ()> + Send
fn upgrade(&self, upgrade: Upgrade) -> impl Future<Output = ()> + Send
This will only be called if the handler reponds true to
Handler::has_upgrade and will
only be called once for this upgrade. There is no return value, and this function takes
exclusive ownership of the underlying transport once this is called. You can downcast
the transport to whatever the source transport type is and perform any non-http protocol
communication that has been negotiated. You probably don’t want this unless you’re
implementing something like websockets. Please note that for many transports such as
TcpStreams, dropping the transport (and therefore the Upgrade) will hang up /
disconnect.Auto Trait Implementations
impl Freeze for StaticFileHandler
impl RefUnwindSafe for StaticFileHandler
impl Send for StaticFileHandler
impl Sync for StaticFileHandler
impl Unpin for StaticFileHandler
impl UnsafeUnpin for StaticFileHandler
impl UnwindSafe for StaticFileHandler